# Apptio Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/apptio-integration#overview)
  * [Integration Use Case: Application Portfolio Management](https://help.sap.com/docs/leanix/ea/apptio-integration#integration-use-case:-application-portfolio-management)
  * [Integration Use Case: Application Rationalization](https://help.sap.com/docs/leanix/ea/apptio-integration#integration-use-case:-application-rationalization)
  * [Integration Use Case: Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/apptio-integration#integration-use-case:-technology-risk-and-compliance)
  * [Integration Use Case: Cloud Migration](https://help.sap.com/docs/leanix/ea/apptio-integration#integration-use-case:-cloud-migration)
  * [How the Integration Works](https://help.sap.com/docs/leanix/ea/apptio-integration#how-the-integration-works)
  * [Base Integration](https://help.sap.com/docs/leanix/ea/apptio-integration#base-integration)
  * [Advanced Integration](https://help.sap.com/docs/leanix/ea/apptio-integration#advanced-integration)


View all
With the out-of-the-box Apptio integration in SAP LeanIX, you will get a holistic overview of your business, IT and finances.
